<?php
namespace Folha\Entities;

use HCM\Util\DateUtil;
use Importacao\Logic\Integracao\ProjetoImportacao;

class MigFerias extends Base\MigFerias
{

    const DEFAULT_NTTIPOFERIAS = '1';

    /**
     * @param $nrferias
     * @return \Folha\Entities\MigFerias
     */
    public function setNrferias ($nrferias) {
        $nrferias = \Importacao\Logic\Validacoes::verificaChaveDuplicada('FPA_FERIAS', 'NRFERIAS', ProjetoImportacao::getNrorg(), $nrferias);
        $this->nrferias = $nrferias;
    }

    /**
     * @param $nrvinculom
     * @return \Folha\Entities\MigFerias
     */
    public function setNrvinculom ($nrvinculom) {
        $nrvinculom = \Importacao\Logic\Validacoes::verificaChaveMae('GPE_VINCULOM', 'NRVINCULOM', ProjetoImportacao::getNrorg(), $nrvinculom);
        $this->nrvinculom = $nrvinculom;
    }

    /**
     * @param $nrtipoferias
     * @return \Folha\Entities\MigFerias
     */
    public function setNrtipoferias ($nrtipoferias) {
        $nrorg = ProjetoImportacao::getNrorgPadrao();
        $tipoferias = \Folha\Entities\FpaTipoferiasm::findOneByNrtipoferiasAndNrorg($nrtipoferias, $nrorg);

        if (is_object($tipoferias)) {
            $this->nrtipoferias = $nrtipoferias;
        } else {
            $this->nrtipoferias = self::DEFAULT_NTTIPOFERIAS;
//            throw new \Exception("O código do Tipo de Férias '$nrtipoferias' não foi encontrado.");
        }
    }

    /**
     * @param $idcontrolferias
     * @return \Folha\Entities\MigFerias
     */
    public function setIdcontrolferias ($idcontrolferias) {
        $this->idcontrolferias = $idcontrolferias;
    }

    /**
     * @param $dtiniaquisicao
     * @throws \Exception
     * @return \Folha\Entities\MigFerias
     */
    public function setDtiniaquisicao ($dtiniaquisicao) {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtiniaquisicao)) {
            throw new \Exception("Campo Obrigatório - Dt. Início Aquisição: Data '$dtiniaquisicao' com formato inválido ou em branco.");
        }

        if (!($dtiniaquisicao instanceof \DateTime)) {
            $dtiniaquisicao = DateUtil::getDataDeString($dtiniaquisicao);
        }

        $this->dtiniaquisicao = $dtiniaquisicao;
    }

    /**
     * @param $dtfimaquisicao
     * @throws \Exception
     * @return \Folha\Entities\MigFerias
     */
    public function setDtfimaquisicao ($dtfimaquisicao) {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtfimaquisicao)) {
            throw new \Exception("Campo Obrigatório - Dt. Fim Aquisição: Data '$dtfimaquisicao' com formato inválido ou em branco.");
        }

        if (!($dtfimaquisicao instanceof \DateTime)) {
            $dtfimaquisicao = DateUtil::getDataDeString($dtfimaquisicao);
        }

        $this->dtfimaquisicao = $dtfimaquisicao;
    }

    /**
     * @param $dtultatu
     * @throws \Exception
     * @return \Folha\Entities\MigFerias
     */
    public function setDtultatu ($dtultatu) {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtultatu)) {
            throw new \Exception("Data '$dtultatu' com formato inválido ou em branco.");
        }

        if (!($dtultatu instanceof \DateTime)) {
            $dtultatu = DateUtil::getDataDeString($dtultatu);
        }

        $this->dtultatu = $dtultatu;
    }

    /**
     * @param $dtinclusao
     * @throws \Exception
     * @return \Folha\Entities\MigFerias
     */
    public function setDtinclusao ($dtinclusao) {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtinclusao)) {
            throw new \Exception("Data '$dtinclusao' com formato inválido ou em branco.");
        }

        if (!($dtinclusao instanceof \DateTime)) {
            $dtinclusao = DateUtil::getDataDeString($dtinclusao);
        }

        $this->dtinclusao = $dtinclusao;
    }

}