/* Tabela PARAMESTOQUE - PARAMFILIAL */
/* Descrio: A trigger insere registros na tabela LOGOPERAESPE a partir de alteraes na tabela PARAMESTOQUE - PARAMFILAL */
/* Objetivo: Gerar um log que vai registrar as alteraes na tabela PARAMESTOQUE - PARAMFILIAL
             utilizando a tabela Geral de Logs de Operaes especficas*/
/* Criao:
/* 25/05/2007 - Fabrcio Marcelo Silva */

/* PARAMETROS DO ESTOQUE */
CREATE OR REPLACE TRIGGER SDXLOG_PARAESTO
AFTER INSERT OR UPDATE ON PARAMESTOQUE FOR EACH ROW
DECLARE
   V_IDUTLOGPARAMETR  VARCHAR2(1);
   V_IDTIPOOPER       VARCHAR2(1);  /* V_IDTIPOOPER - 'I' - Incluso, 'A' - Alterao */
   V_CLIENT_INFO      VARCHAR2(64);
   V_CDOPERADOR       VARCHAR2(12);
   V_DESC             VARCHAR2(2000);
BEGIN
   BEGIN
      SELECT IDUTLOGPARAMETR
      INTO V_IDUTLOGPARAMETR
      FROM PARAMGERAL
      WHERE CDPARGERAL = '0001';
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_IDUTLOGPARAMETR := 'N';
   END;

   IF V_IDUTLOGPARAMETR = 'S' THEN

      V_IDTIPOOPER  := '';
      V_CLIENT_INFO := '';
      V_CDOPERADOR  := '';
      V_DESC        := '';

      /* Retorna o codigo e o nome do operador */
      DBMS_APPLICATION_INFO.READ_CLIENT_INFO(V_CLIENT_INFO);
      V_CDOPERADOR := SUBSTR(V_CLIENT_INFO,1,12);

      IF UPDATING THEN
         IF (NVL(:OLD.IDLANCDTMEN,'')  <> NVL(:NEW.IDLANCDTMEN,''))  THEN
            V_DESC := V_DESC || 'Permite Lanc. Anteriores A dt. processamento:'  || ' ' || :NEW.IDLANCDTMEN  || ' ';
            V_IDTIPOOPER := 'A';
         END IF;
         IF (NVL(:OLD.NRDIASENTR,0)     <> NVL(:NEW.NRDIASENTR,0))     THEN
            V_DESC := V_DESC || 'Dias p/ lanc. Entrada ant.:'                    || ' ' || :NEW.NRDIASENTR   || ' ';
            V_IDTIPOOPER := 'A';
         END IF;
         IF (NVL(:OLD.NRDIASSAID,0)     <> NVL(:NEW.NRDIASSAID,0))     THEN
            V_DESC := V_DESC || 'Dias p/ lanc. Sada ant.:'                      || ' ' || :NEW.NRDIASSAID   || ' ';
            V_IDTIPOOPER := 'A';
         END IF;
         IF (NVL(:OLD.NRDIASAJUS,0)     <> NVL(:NEW.NRDIASAJUS,0))     THEN
            V_DESC := V_DESC || 'Dias p/ lanc. Ajustes/Implantao ant.:'        || ' ' || :NEW.NRDIASAJUS   || ' ';
            V_IDTIPOOPER := 'A';
         END IF;
         IF (NVL(:OLD.IDLANCDTMAI,'')  <> NVL(:NEW.IDLANCDTMAI,''))  THEN
            V_DESC := V_DESC || 'Permite Lanc. Posteriores  Dt. Processamento:' || ' ' || :NEW.IDLANCDTMAI  || ' ';
            V_IDTIPOOPER := 'A';
         END IF;
         IF (NVL(:OLD.NRDIASENTRPD,0)   <> NVL(:NEW.NRDIASENTRPD,0))   THEN
            V_DESC := V_DESC || 'Dias p/ lanc. Entrada post.:'                   || ' ' || :NEW.NRDIASENTRPD || ' ';
            V_IDTIPOOPER := 'A';
         END IF;
         IF (NVL(:OLD.NRDIASSAIDPD,0)   <> NVL(:NEW.NRDIASSAIDPD,0))   THEN
            V_DESC := V_DESC || 'Dias p/ lanc. Sada post.:'                     || ' ' || :NEW.NRDIASSAIDPD || ' ';
            V_IDTIPOOPER := 'A';
         END IF;
         IF (NVL(:OLD.NRDIASAJUSPD,0)   <> NVL(:NEW.NRDIASAJUSPD,0))   THEN
            V_DESC := V_DESC || 'Dias p/ lanc. Ajustes/Implantao post.:'       || ' ' || :NEW.NRDIASAJUSPD;
            V_IDTIPOOPER := 'A';
         END IF;
      ELSE
         V_IDTIPOOPER := 'I';

         V_DESC := 'Permite Lanc. Anteriores A dt. processamento:'  || ' ' || :NEW.IDLANCDTMEN  || ' ' ||
                   'Dias p/ lanc. Entrada ant.:'                    || ' ' || :NEW.NRDIASENTR   || ' ' ||
                   'Dias p/ lanc. Sada ant.:'                      || ' ' || :NEW.NRDIASSAID   || ' ' ||
                   'Dias p/ lanc. Ajustes/Implantao ant.:'        || ' ' || :NEW.NRDIASAJUS   || ' ' ||
                   'Permite Lanc. Posteriores  Dt. Processamento:' || ' ' || :NEW.IDLANCDTMAI  || ' ' ||
                   'Dias p/ lanc. Entrada post.:'                   || ' ' || :NEW.NRDIASENTRPD || ' ' ||
                   'Dias p/ lanc. Sada post.:'                     || ' ' || :NEW.NRDIASSAIDPD || ' ' ||
                   'Dias p/ lanc. Ajustes/Implantao post.:'       || ' ' || :NEW.NRDIASAJUSPD;

      END IF;

      IF NOT (V_DESC IS NULL)       AND
         NOT (V_IDTIPOOPER IS NULL) THEN

         V_DESC := SUBSTR(V_DESC, 1, 2000);

         INSERT INTO LOGOPERAESPE (NMOPERAESPE,     DTOPERAESPE,     IDOPERAESPE,
                                   CDOPERRESPOPERA, DSOPERAESPE)
                     VALUES ('Parametros Estoque', SYSDATE,      V_IDTIPOOPER,
                             V_CDOPERADOR, V_DESC);
      END IF;
   END IF;
END;
/


/* PARAMETROS DO ESTOQUE POR FILIAl*/
CREATE OR REPLACE TRIGGER SDXLOG_PARAESTOFILI
AFTER INSERT OR UPDATE ON PARAMFILIAL FOR EACH ROW
DECLARE
   V_IDUTLOGPARAMETR  VARCHAR2(1);
   V_IDTIPOOPER       VARCHAR2(1);  /* V_IDTIPOOPER - 'I' - Incluso, 'A' - Alterao */
   V_CLIENT_INFO      VARCHAR2(64);
   V_CDOPERADOR       VARCHAR2(12);
   V_CDFILIAL         VARCHAR2(4);
   V_DESC             VARCHAR2(2000);

   V_DSREMOTEADDR     VARCHAR2(15);
   V_DSREMOTEHOST     VARCHAR2(15);
   V_DSSERVERRDM      VARCHAR2(20);
   V_DSSERVMETHOD     VARCHAR2(30);
   V_DSREMOTEOPER     VARCHAR2(12);
BEGIN
   WEBTUNNING(V_DSREMOTEADDR,
              V_DSREMOTEHOST,
              V_DSSERVERRDM,
              V_DSSERVMETHOD,
              V_DSREMOTEOPER);

   IF SUBSTR(V_DSSERVERRDM,1,11) <> 'rdmFechaDia' THEN
      BEGIN
         SELECT IDUTLOGPARAMETR
         INTO V_IDUTLOGPARAMETR
         FROM PARAMGERAL
         WHERE CDPARGERAL = '0001';
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_IDUTLOGPARAMETR := 'N';
      END;

      IF V_IDUTLOGPARAMETR = 'S' THEN

         V_IDTIPOOPER  := '';
         V_CLIENT_INFO := '';
         V_CDOPERADOR  := '';
         V_CDFILIAL    := '';
         V_DESC        := '';

         /* Retorna o codigo e o nome do operador */
         DBMS_APPLICATION_INFO.READ_CLIENT_INFO(V_CLIENT_INFO);
         V_CDOPERADOR := SUBSTR(V_CLIENT_INFO,1,12);

         IF UPDATING THEN

            V_CDFILIAL   := :NEW.CDFILIAL;

            V_DESC    := 'Filial:'                                      || ' ' || :NEW.CDFILIAL       || ' ';

            IF (NVL(:OLD.IDCTRLESTQ, '')     <> NVL(:NEW.IDCTRLESTQ, ''))     THEN
               V_DESC := V_DESC || 'Controla Estoque:'                            || ' ' || :NEW.IDCTRLESTQ     || ' ';
               V_IDTIPOOPER := 'A';
            END IF;
            IF (NVL(:OLD.IDESTONLINE, '')    <> NVL(:NEW.IDESTONLINE, ''))    THEN
               V_DESC := V_DESC || 'Realiza Atualizao On-line Mov. Estoque:'    || ' ' || :NEW.IDESTONLINE    || ' ';
               V_IDTIPOOPER := 'A';
            END IF;
            IF (NVL(:OLD.IDPERMESTNEG, '')   <> NVL(:NEW.IDPERMESTNEG, ''))   THEN
               V_DESC := V_DESC || 'Permite Lanc. geram Valores Neg. p/ Estoque:' || ' ' || :NEW.IDPERMESTNEG   || ' ';
               V_IDTIPOOPER := 'A';
            END IF;
            IF (NVL(:OLD.DTPROCESSA, SYSDATE) <> NVL(:NEW.DTPROCESSA, SYSDATE)) THEN
               V_DESC := V_DESC || 'Data de Processamento:'                       || ' ' || TO_CHAR(:NEW.DTPROCESSA, 'DD/MM/YYYY')  || ' ';
               V_IDTIPOOPER := 'A';
            END IF;
            IF (NVL(:OLD.IDUTILALMOX, '')    <> NVL(:NEW.IDUTILALMOX, ''))    THEN
               V_DESC := V_DESC || 'Utiliza Controle por Almoxarifado:'           || ' ' || :NEW.IDUTILALMOX    || ' ';
               V_IDTIPOOPER := 'A';
            END IF;
            IF (NVL(:OLD.IDUTILLCESTQ, '')   <> NVL(:NEW.IDUTILLCESTQ, ''))   THEN
               V_DESC := V_DESC || 'Utiliza Controle por Local de Estoque:'       || ' ' || :NEW.IDUTILLCESTQ   || ' ';
               V_IDTIPOOPER := 'A';
            END IF;
            IF (NVL(:OLD.IDUTILLOTE, '')     <> NVL(:NEW.IDUTILLOTE, ''))     THEN
               V_DESC := V_DESC || 'Utiliza Controle de Lote:'                    || ' ' || :NEW.IDUTILLOTE     || ' ';
               V_IDTIPOOPER := 'A';
            END IF;
            IF (NVL(:OLD.NRTAMNUMNFUT, 0)     <> NVL(:NEW.NRTAMNUMNFUT, 0))     THEN
               V_DESC := V_DESC || 'Tamanho do N da Nota Fiscal:'                || ' ' || :NEW.NRTAMNUMNFUT;
               V_IDTIPOOPER := 'A';
            END IF;
         ELSE
            V_IDTIPOOPER := 'I';
            V_CDFILIAL   := :NEW.CDFILIAL;

            V_DESC := 'Filial:'                                      || ' ' || :NEW.CDFILIAL       || ' ' ||
                      'Controla Estoque:'                            || ' ' || :NEW.IDCTRLESTQ     || ' ' ||
                      'Realiza Atualizao On-line Mov. Estoque:'    || ' ' || :NEW.IDESTONLINE    || ' ' ||
                      'Permite Lanc. geram Valores Neg. p/ Estoque:' || ' ' || :NEW.IDPERMESTNEG   || ' ' ||
                      'Data de Processamento:'                       || ' ' || TO_CHAR(:NEW.DTPROCESSA, 'DD/MM/YYYY')  || ' ' ||
                      'Utiliza Controle por Almoxarifado:'           || ' ' || :NEW.IDUTILALMOX    || ' ' ||
                      'Utiliza Controle por Local de Estoque:'       || ' ' || :NEW.IDUTILLCESTQ   || ' ' ||
                      'Utiliza Controle de Lote:'                    || ' ' || :NEW.IDUTILLOTE     || ' ' ||
                      'Tamanho do N da Nota Fiscal:'                || ' ' || :NEW.NRTAMNUMNFUT;
         END IF;

         IF NOT (V_DESC IS NULL)       AND
            NOT (V_IDTIPOOPER IS NULL) THEN

            V_DESC := SUBSTR(V_DESC, 1, 2000);

            INSERT INTO LOGOPERAESPE (NMOPERAESPE,     DTOPERAESPE,     IDOPERAESPE,
                                      CDOPERRESPOPERA, DSOPERAESPE, CDFILIRESPOPERA)
                        VALUES ('Parametros Estoque/DFE/DFS', SYSDATE,      V_IDTIPOOPER,
                                V_CDOPERADOR, V_DESC, V_CDFILIAL);
         END IF;
      END IF;
   END IF;
END;
/


/* PARAMETROS DOCUMENTOS FISCAIS DE ENTRADA E DOCUMETOS FISCAIS DE SADA*/
CREATE OR REPLACE TRIGGER SDXLOG_PARAMETDFEDFS
AFTER INSERT OR UPDATE ON PARAMGERAL FOR EACH ROW
DECLARE
   V_IDTIPOOPER       VARCHAR2(1);  /* V_IDTIPOOPER - 'I' - Incluso, 'A' - Alterao */
   V_CLIENT_INFO      VARCHAR2(64);
   V_CDOPERADOR       VARCHAR2(12);
   V_CDFILIAL         VARCHAR2(4);
   V_DESC             VARCHAR2(2000);
BEGIN
   IF :NEW.IDUTLOGPARAMETR = 'S' THEN

      V_IDTIPOOPER  := '';
      V_CLIENT_INFO := '';
      V_CDOPERADOR  := '';
      V_CDFILIAL    := '';
      V_DESC        := '';

      /* Retorna o codigo e o nome do operador */
      DBMS_APPLICATION_INFO.READ_CLIENT_INFO(V_CLIENT_INFO);
      V_CDOPERADOR := SUBSTR(V_CLIENT_INFO,1,12);

      IF UPDATING THEN

         V_CDFILIAL   := :NEW.CDFILIAL;

         V_DESC    := 'Filial:'                                      || ' ' || :NEW.CDFILIAL;

         IF (NVL(:OLD.NRDECITOTANF, 0)   <> NVL(:NEW.NRDECITOTANF, 0))   THEN
            V_DESC := V_DESC || ' '|| 'N Casas Decimais Totalizacoes:'        || ' ' || :NEW.NRDECITOTANF;
            V_IDTIPOOPER := 'A';
         END IF;
         IF (NVL(:OLD.VRPETOLEVRAF, 0)   <> NVL(:NEW.VRPETOLEVRAF, 0))   THEN
            V_DESC := V_DESC || ' '|| 'Tolerancia Permitida p/ Valores (%):'   || ' ' || :NEW.VRPETOLEVRAF;
            V_IDTIPOOPER := 'A';
         END IF;
         IF (NVL(:OLD.VRPETOLEQTAF, 0)   <> NVL(:NEW.VRPETOLEQTAF, 0))   THEN
            V_DESC := V_DESC || ' '|| 'Tolerncia Permitida p/ Qtde. (%):'     || ' ' || :NEW.VRPETOLEQTAF;
            V_IDTIPOOPER := 'A';
         END IF;
         IF (NVL(:OLD.IDCONSVLRMAF, '') <> NVL(:NEW.IDCONSVLRMAF, '')) THEN
            V_DESC := V_DESC || ' '|| 'Consiste qtde. menor que a da AF:'      || ' ' || :NEW.IDCONSVLRMAF;
            V_IDTIPOOPER := 'A';
         END IF;
         IF (NVL(:OLD.IDBLOQCMPSAF, '') <> NVL(:NEW.IDBLOQCMPSAF, '')) THEN
            V_DESC := V_DESC || ' '|| 'Bloqueia NF de Compra sem AF:'          || ' ' || :NEW.IDBLOQCMPSAF;
            V_IDTIPOOPER := 'A';
         END IF;
         IF (NVL(:OLD.IDCONSFISCSA, 0)   <> NVL(:NEW.IDCONSFISCSA, 0))   THEN
            V_DESC := V_DESC || ' '|| 'Realiza Cons. Fiscais no Fech. NF:'     || ' ' || :NEW.IDCONSFISCSA;
            V_IDTIPOOPER := 'A';
         END IF;
         IF (NVL(:OLD.IDBLOQVENPR, '')  <> NVL(:NEW.IDBLOQVENPR, ''))  THEN
            V_DESC := V_DESC || ' '|| 'Bloq. Inc. do Mesmo Prod. na NF Venda:' || ' ' || :NEW.IDBLOQVENPR;
            V_IDTIPOOPER := 'A';
         END IF;
      ELSE
         V_IDTIPOOPER := 'I';

         V_CDFILIAL   := :NEW.CDFILIAL;

         V_DESC := 'N Casas Decimais Totalizacoes:'        || ' ' || :NEW.NRDECITOTANF  || ' ' ||
                   'Tolerancia Permitida p/ Valores (%):'   || ' ' || :NEW.VRPETOLEVRAF  || ' ' ||
                   'Tolerncia Permitida p/ Qtde. (%):'     || ' ' || :NEW.VRPETOLEQTAF  || ' ' ||
                   'Consiste qtde. menor que a da AF:'      || ' ' || :NEW.IDCONSVLRMAF  || ' ' ||
                   'Bloqueia NF de Compra sem AF:'          || ' ' || :NEW.IDBLOQCMPSAF  || ' ' ||
                   'Realiza Cons. Fiscais no Fech. NF:'     || ' ' || :NEW.IDCONSFISCSA  || ' ' ||
                   'Bloq. Inc. do Mesmo Prod. na NF Venda:' || ' ' || :NEW.IDBLOQVENPR;
      END IF;

      IF NOT (V_DESC IS NULL)       AND
         NOT (V_IDTIPOOPER IS NULL) THEN

         V_DESC := SUBSTR(V_DESC, 1, 2000);

         INSERT INTO LOGOPERAESPE (NMOPERAESPE,     DTOPERAESPE,     IDOPERAESPE,
                                   CDOPERRESPOPERA, DSOPERAESPE, CDFILIRESPOPERA)
                     VALUES ('Parametros DFE/DFS',  SYSDATE,      V_IDTIPOOPER,
                             V_CDOPERADOR, V_DESC, V_CDFILIAL);
      END IF;
   END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('SDXLOG_PARAMETDFEDFS','5.05.021'); END;
/

